<?php

namespace App\Http\Livewire\Public\Tools;

use Livewire\Component;
use App\Models\Admin\History;
use App\Classes\TextRepeaterClass;
use DateTime;
use GeoIp2\Database\Reader;
use GeoIp2\Exception\AddressNotFoundException;
use App\Rules\VerifyRecaptcha;
use App\Models\Admin\General;

class TextRepeater extends Component
{
    public $text;
    public $repetitions;
    public $text_between_repetitions;
    public $newline = 0;
    public $data = [];
    public $recaptcha;

    public function render()
    {
        return view('livewire.public.tools.text-repeater');
    }

    /**
     * -------------------------------------------------------------------------------
     *  onTextRepeater
     * -------------------------------------------------------------------------------
    **/
    public function onTextRepeater(){

        $validationRules = [
            'text' => 'required',
        ];

        if (General::first()->captcha_status) {
            $validationRules['recaptcha'] = ['required', new VerifyRecaptcha];
        }

        $this->validate($validationRules);

        $this->data = null;

        try {

            $output = new TextRepeaterClass();

            $this->data = $output->get_data( $this->text, $this->repetitions, $this->text_between_repetitions, $this->newline );

            $this->dispatchBrowserEvent('resetReCaptcha');

        } catch (\Exception $e) {

            $this->addError('error', __($e->getMessage()));
        }

        //Save History
        if ( !empty($this->data) ) {

            $history             = new History;
            $history->tool_name  = 'Text Repeater';
            $history->client_ip  = request()->ip();

            require app_path('Classes/geoip2.phar');

            $reader = new Reader( app_path('Classes/GeoLite2-City.mmdb') );

            try {

                $record           = $reader->city( request()->ip() );

                $history->flag    = strtolower( $record->country->isoCode );
                
                $history->country = strip_tags( $record->country->name );

            } catch (AddressNotFoundException $e) {

            }

            $history->created_at = new DateTime();
            $history->save();
        }

    }

    /**
     * -------------------------------------------------------------------------------
     *  onSample
     * -------------------------------------------------------------------------------
    **/
    public function onSample()
    {
        $this->text                     = 'Hello';
        $this->repetitions              = 12;
        $this->text_between_repetitions = ', ';
    }

    /**
     * -------------------------------------------------------------------------------
     *  onReset
     * -------------------------------------------------------------------------------
    **/
    public function onReset()
    {
        $this->text                     = null;
        $this->data                     = null;
        $this->repetitions              = null;
        $this->text_between_repetitions = null;
        $this->newline                  = 0;
    }
}
